@@ -4,7 +4,7 @@ import logging
 
 from flexget import plugin
 from flexget.event import event
-from flexget.utils.template import render_from_task, get_template
+from flexget.utils.template import render_from_task, get_template, RenderError
 
 PLUGIN_NAME = 'make_html'
 
@@ -35,11 +35,14 @@ class OutputHtml:
             output = os.path.join(task.manager.config_base, output)
 
         # create the template
-        template = render_from_task(get_template(filename, PLUGIN_NAME), task)
-
-        log.verbose('Writing output html to %s' % output)
-        with open(output, 'w') as f:
-            f.write(template.encode('utf-8'))
+        try:
+            template = render_from_task(get_template(filename, PLUGIN_NAME), task)
+            log.verbose('Writing output html to %s' % output)
+            with open(output, 'w') as f:
+                f.write(template.encode('utf-8'))
+        except RenderError as e:
+            log.error('Error while rendering task %s, Error: %s' % (task, e))
+            raise plugin.PluginError('There was an error rendering the specified template')
 
 @event('plugin.register')
 def register_plugin():
